@@ -1,6 +1,5 @@
 import * as Sentry from "@sentry/browser";
 import React, { useState, useEffect } from "react";
-import { sortBy } from "lodash";
 import {
   BrowserRouter,
   Switch,
@@ -10,6 +9,7 @@ import {
 } from "react-router-dom";
 import "./App.css";
 import { ContextMenu } from "./ContextMenu";
+import { Tooltip } from "./Tooltip";
 import { HomePage, QueryPage, Logo, EditSavedView } from "./Components";
 import { Query, getUrlForQuery, empty } from "./Query";
 import { doGet, fetchInProgress } from "./Util";
@@ -119,9 +119,7 @@ function QueryApp(props) {
     fetchResults(newState)
       .then((response) => {
         const res = { ...response, ...empty };
-        res.filters = sortBy(res.filters, ["pathStr"]);
         const req = { ...request };
-        req.filters = sortBy(req.filters, ["pathStr"]);
         assert.deepStrictEqual(res, req);
       })
       .catch(handleError);
@@ -145,20 +143,22 @@ function App(props) {
   return (
     <BrowserRouter basename={baseUrl}>
       <ContextMenu>
-        <Logo />
-        <div id="body">
-          <Switch>
-            <Route path="/query/:model/:fieldStr?.html">
-              <QueryApp config={props} />
-            </Route>
-            <Route path="/views/:pk.html">
-              <EditSavedView {...{ baseUrl, canMakePublic }} />
-            </Route>
-            <Route path="/">
-              <HomePage {...props} />
-            </Route>
-          </Switch>
-        </div>
+        <Tooltip>
+          <Logo />
+          <div id="body">
+            <Switch>
+              <Route path="/query/:model/:fieldStr?.html">
+                <QueryApp config={props} />
+              </Route>
+              <Route path="/views/:pk.html">
+                <EditSavedView {...{ baseUrl, canMakePublic }} />
+              </Route>
+              <Route path="/">
+                <HomePage {...props} />
+              </Route>
+            </Switch>
+          </div>
+        </Tooltip>
       </ContextMenu>
     </BrowserRouter>
   );
